# Reference

<!-- DO NOT EDIT: This document was generated by Puppet Strings -->

## Table of Contents

### Classes

* [`node_orchestration::aws`](#node_orchestration--aws): Configure pre-requisites for puppetlabs-aws module
* [`node_orchestration::azure`](#node_orchestration--azure): Configure Azure CLI needed by this module's plans

### Plans

* [`node_orchestration::bootstrap_agent`](#node_orchestration--bootstrap_agent): Register a new node in the PE inventory and run pe_bootstrap against it
* [`node_orchestration::create_azure_vm`](#node_orchestration--create_azure_vm): Create an Azure VM with default settings
* [`node_orchestration::launch_ec2_instance`](#node_orchestration--launch_ec2_instance): Create an EC2 instance with default settings

## Classes

### <a name="node_orchestration--aws"></a>`node_orchestration::aws`

Configure pre-requisites for puppetlabs-aws module

* **See also**
  * https://forge.puppet.com/modules/puppetlabs/aws

#### Parameters

The following parameters are available in the `node_orchestration::aws` class:

* [`access_key_id`](#-node_orchestration--aws--access_key_id)
* [`secret_access_key`](#-node_orchestration--aws--secret_access_key)
* [`region`](#-node_orchestration--aws--region)

##### <a name="-node_orchestration--aws--access_key_id"></a>`access_key_id`

Data type: `String`

IAM access key with EC2 privileges

##### <a name="-node_orchestration--aws--secret_access_key"></a>`secret_access_key`

Data type: `Sensitive`

IAM secret access key associated with the access key ID

##### <a name="-node_orchestration--aws--region"></a>`region`

Data type: `String`

The default AWS region to interact with

### <a name="node_orchestration--azure"></a>`node_orchestration::azure`

Configure Azure CLI needed by this module's plans

* **See also**
  * https://forge.puppet.com/modules/puppetlabs/azure

#### Parameters

The following parameters are available in the `node_orchestration::azure` class:

* [`tenant_id`](#-node_orchestration--azure--tenant_id)
* [`client_id`](#-node_orchestration--azure--client_id)
* [`client_secret`](#-node_orchestration--azure--client_secret)

##### <a name="-node_orchestration--azure--tenant_id"></a>`tenant_id`

Data type: `String`

The Azure AD tenant ID containing your app registration

##### <a name="-node_orchestration--azure--client_id"></a>`client_id`

Data type: `String`

The ID associated with your app registration

##### <a name="-node_orchestration--azure--client_secret"></a>`client_secret`

Data type: `Sensitive`

The password assigned to your app registration

## Plans

### <a name="node_orchestration--bootstrap_agent"></a>`node_orchestration::bootstrap_agent`

Register a new node in the PE inventory and run pe_bootstrap against it

#### Parameters

The following parameters are available in the `node_orchestration::bootstrap_agent` plan:

* [`name`](#-node_orchestration--bootstrap_agent--name)
* [`hostname`](#-node_orchestration--bootstrap_agent--hostname)
* [`user`](#-node_orchestration--bootstrap_agent--user)
* [`password`](#-node_orchestration--bootstrap_agent--password)
* [`role`](#-node_orchestration--bootstrap_agent--role)

##### <a name="-node_orchestration--bootstrap_agent--name"></a>`name`

Data type: `String`

The desired node certname

##### <a name="-node_orchestration--bootstrap_agent--hostname"></a>`hostname`

Data type: `Stdlib::Host`

The real hostname or IP address of the node to bootstrap

##### <a name="-node_orchestration--bootstrap_agent--user"></a>`user`

Data type: `String`

The SSH user to bootstrap with

##### <a name="-node_orchestration--bootstrap_agent--password"></a>`password`

Data type: `Optional[Sensitive]`



Default value: `undef`

##### <a name="-node_orchestration--bootstrap_agent--role"></a>`role`

Data type: `Optional[String]`



Default value: `undef`

### <a name="node_orchestration--create_azure_vm"></a>`node_orchestration::create_azure_vm`

Create an Azure VM with default settings

#### Parameters

The following parameters are available in the `node_orchestration::create_azure_vm` plan:

* [`vm_name`](#-node_orchestration--create_azure_vm--vm_name)
* [`size`](#-node_orchestration--create_azure_vm--size)
* [`image_id`](#-node_orchestration--create_azure_vm--image_id)
* [`admin_user`](#-node_orchestration--create_azure_vm--admin_user)
* [`admin_password`](#-node_orchestration--create_azure_vm--admin_password)
* [`public_ip_address`](#-node_orchestration--create_azure_vm--public_ip_address)
* [`resource_group`](#-node_orchestration--create_azure_vm--resource_group)
* [`os_disk_size`](#-node_orchestration--create_azure_vm--os_disk_size)
* [`data_disk_sizes`](#-node_orchestration--create_azure_vm--data_disk_sizes)
* [`role`](#-node_orchestration--create_azure_vm--role)

##### <a name="-node_orchestration--create_azure_vm--vm_name"></a>`vm_name`

Data type: `String`

The name of the VM to create

##### <a name="-node_orchestration--create_azure_vm--size"></a>`size`

Data type: `Enum['small', 'medium', 'large']`

The type of VM to create (small, medium, large)

##### <a name="-node_orchestration--create_azure_vm--image_id"></a>`image_id`

Data type: `Optional[String]`

Overrides the default image ID set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--admin_user"></a>`admin_user`

Data type: `Optional[String]`

Overrides the initial VM username set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--admin_password"></a>`admin_password`

Data type: `Optional[Sensitive]`

Overrides the initial VM password set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--public_ip_address"></a>`public_ip_address`

Data type: `Optional[Boolean]`

Overrides Hiera setting on whether to assign a public IP address

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--resource_group"></a>`resource_group`

Data type: `Optional[String]`

Overrides the resource group set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--os_disk_size"></a>`os_disk_size`

Data type: `Optional[Integer]`

If set, the size of the OS disk in GB. Otherwise, use Azure defaults.

Default value: `undef`

##### <a name="-node_orchestration--create_azure_vm--data_disk_sizes"></a>`data_disk_sizes`

Data type: `Array[Integer]`

The sizes of the data disks to attach in GB

Default value: `[]`

##### <a name="-node_orchestration--create_azure_vm--role"></a>`role`

Data type: `Optional[String]`

Set the `pp_role` extension request (trusted fact) to this value

Default value: `undef`

### <a name="node_orchestration--launch_ec2_instance"></a>`node_orchestration::launch_ec2_instance`

Create an EC2 instance with default settings

#### Parameters

The following parameters are available in the `node_orchestration::launch_ec2_instance` plan:

* [`instance_name`](#-node_orchestration--launch_ec2_instance--instance_name)
* [`size`](#-node_orchestration--launch_ec2_instance--size)
* [`image_id`](#-node_orchestration--launch_ec2_instance--image_id)
* [`ami_user`](#-node_orchestration--launch_ec2_instance--ami_user)
* [`key_name`](#-node_orchestration--launch_ec2_instance--key_name)
* [`public_ip_address`](#-node_orchestration--launch_ec2_instance--public_ip_address)
* [`security_groups`](#-node_orchestration--launch_ec2_instance--security_groups)
* [`subnet`](#-node_orchestration--launch_ec2_instance--subnet)
* [`region`](#-node_orchestration--launch_ec2_instance--region)
* [`os_disk_size`](#-node_orchestration--launch_ec2_instance--os_disk_size)
* [`role`](#-node_orchestration--launch_ec2_instance--role)

##### <a name="-node_orchestration--launch_ec2_instance--instance_name"></a>`instance_name`

Data type: `String`

The name of the instance to create

##### <a name="-node_orchestration--launch_ec2_instance--size"></a>`size`

Data type: `Enum['small', 'medium', 'large']`

The type of instance to create

##### <a name="-node_orchestration--launch_ec2_instance--image_id"></a>`image_id`

Data type: `Optional[String]`

Overrides the default AMI set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--ami_user"></a>`ami_user`

Data type: `Optional[String]`

Overrides the default AMI username set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--key_name"></a>`key_name`

Data type: `Optional[String]`

Overrides the default SSH key name set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--public_ip_address"></a>`public_ip_address`

Data type: `Optional[Boolean]`

Overrides Hiera setting on whether to assign a public IP
address. Subnet default takes priority.

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--security_groups"></a>`security_groups`

Data type: `Optional[Array[String]]`

Overrides the default SG or list of SGs set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--subnet"></a>`subnet`

Data type: `Optional[String]`

Overrides the default subnet name set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--region"></a>`region`

Data type: `Optional[String]`

Overrides the default region set in Hiera

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--os_disk_size"></a>`os_disk_size`

Data type: `Optional[Integer]`

If set, the size of the OS disk in GB. Otherwise, use EC2 defaults.

Default value: `undef`

##### <a name="-node_orchestration--launch_ec2_instance--role"></a>`role`

Data type: `Optional[String]`

Set the `pp_role` extension request (trusted fact) to this value

Default value: `undef`

